@@ -70,7 +70,7 @@ MultiBrain2 <- R6::R6Class(
         check_freesurfer_path(template_path, autoinstall_template = TRUE)
       }
 
-      # If N27, makesure it's installed
+      # If N27, make sure it's installed
       stopifnot2(check_freesurfer_path(template_path),
                  msg = paste0('Cannot find template subject - ', template_subject,
                               '\nTo install N27 template subject, you can use:\n\n\t',
@@ -79,13 +79,31 @@ MultiBrain2 <- R6::R6Class(
       if( !length( surface_types ) ){
         surface_types <- lapply(self$objects, function(x){ x$surface_types })
         surface_types <- unique(unlist(surface_types))
-      }else{
-        surface_types <- unique(c('pial', unlist( surface_types )))
+      }
+      surface_types <- unique(c('pial', 'pial-outer-smoothed', 'sphere.reg',
+                                unlist( surface_types )))
+
+      # check if pial-outer-smoothed exist
+      lh_envelope <- file.path(template_path, "surf", 'lh.pial-outer-smoothed')
+      rh_envelope <- file.path(template_path, "surf", 'rh.pial-outer-smoothed')
+      if(!file.exists(lh_envelope)) {
+        surface_path <- file.path(template_path, "surf", 'lh.pial')
+        envelope <- generate_smooth_envelope(
+          surface_path = surface_path, save_as = lh_envelope,
+          verbose = TRUE, save_format = "bin"
+        )
+      }
+      if(!file.exists(rh_envelope)) {
+        surface_path <- file.path(template_path, "surf", 'rh.pial')
+        envelope <- generate_smooth_envelope(
+          surface_path = surface_path, save_as = rh_envelope,
+          verbose = TRUE, save_format = "bin"
+        )
       }
 
-      self$template_object <- freesurfer_brain2(
-        fs_subject_folder = template_path, subject_name = template_subject,
-        surface_types = surface_types, use_cache = use_cache, use_141 = use_141)
+      self$template_object <- threeBrain(
+        path = template_path, subject_code = template_subject,
+        surface_types = surface_types, template_subject = template_subject)
     },
 
     add_subject = function(x){
@@ -101,7 +119,7 @@ MultiBrain2 <- R6::R6Class(
 
     localize = function(
       coregistered_ct,
-      col = c("white", "green", 'darkgreen'),
+      col = c("gray80", 'darkgreen'),
       controllers = list(),
       control_presets = NULL,
       voxel_colormap = NULL,
@@ -119,13 +137,13 @@ MultiBrain2 <- R6::R6Class(
         }
 
         cube <- reorient_volume( ct$get_data(), self$Torig )
-        add_voxel_cube(self, "CT", cube)
+        add_voxel_cube(self, "CT", cube, color_format = "RedFormat")
 
         key <- seq(0, max(cube))
         cmap <- create_colormap(
           gtype = 'volume', dtype = 'continuous',
           key = key, value = key,
-          color = col
+          color = c("black", "white")
         )
         controllers[["Voxel Type"]] <- "CT"
         controllers[["Voxel Display"]] <- "normal"
