@@ -38,3 +38,22 @@ import_fs.xform <- function(subject_name, fs_path, quiet = FALSE, dtype, sub_typ
 
 # import_fs('YCQ', fs_path = '~/rave_data/others/fs/', dtype = 'xform')
 
+
+read_xfm <- function(path) {
+  # path <- "/Users/dipterix/Library/Application Support/org.R-project.R/R/threeBrain/templates/cvs_avg35/mri/transforms/talairach.xfm"
+  tryCatch({
+    freesurferformats::read.fs.transform.xfm( path )
+  }, error = function(...) {
+    ss <- readLines(path)
+    ss <- stringr::str_match(ss, '^[ ]{0,}([-]{0,1}[0-9.]+)[ ]{1,}([-]{0,1}[0-9.]+)[ ]{1,}([-]{0,1}[0-9.]+)[ ]{1,}([-]{0,1}[0-9.]+)[ ;]{0,}$')
+    ss <- ss[!is.na(ss[,1]), -1, drop = FALSE]
+    ss <- ss[1:3,1:4]
+
+    ss <- as.numeric(ss)
+    dim(ss) <- c(3,4)
+    list(
+      type = "Linear",
+      matrix = rbind(ss, c(0,0,0,1))
+    )
+  })
+}
